@@ -330,6 +330,7 @@ class Resource:
         SSP_KUBEVIRT_IO = "ssp.kubevirt.io"
         STORAGE_K8S_IO = "storage.k8s.io"
         STORAGECLASS_KUBERNETES_IO = "storageclass.kubernetes.io"
+        SUBRESOURCES_KUBEVIRT_IO = "subresources.kubevirt.io"
         TEKTON_TASKS_KUBEVIRT_IO = "tektontasks.kubevirt.io"
         TEMPLATE_KUBEVIRT_IO = "template.kubevirt.io"
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
@@ -400,6 +401,7 @@ class Resource:
         self.node_selector = node_selector
         self.node_selector_labels = node_selector_labels
         self.node_selector_spec = self._prepare_node_selector_spec()
+        self.res = None
 
     def _prepare_node_selector_spec(self):
         if self.node_selector:
